﻿using Superviseur.Properties;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Data.SQLite;
using System.Drawing;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace Superviseur
{
    public partial class SupervisionFrm : Form
    {

        #region Private members

        private Visualisation_Suivi historique = null;

        #endregion

        public SupervisionFrm()
        {
            InitializeComponent();
        }

        #region Menu action

        private void suiviDesActionsToolStripMenuItem_Click(object sender, EventArgs e)
        {
            DisplayHistorique();
        }


        private void styleApplicationToolStripMenuItem_Click(object sender, EventArgs e)
        {
            DisplayStyle();
        }

        #endregion


        #region Private method tools

        private void HideAllButThis(Control toKeep)
        {
            foreach (Control c in ActionPanel.Controls)
            {
                if (c != toKeep)
                {
                    c.Visible = false;
                }
                else
                {
                    c.Visible = true;
                }
            }
        }

        #endregion


        #region Manager User Control Display

        
        private void DisplayStyle()
        {
            Stylechooser style = new Stylechooser();
            style.ShowDialog();
        }

        private void DisplayHistorique()
        {
            bool needUpdate = true;
            if (historique == null)
            {
                historique = new Visualisation_Suivi();
                this.ActionPanel.Controls.Add(historique);
                historique.Dock = DockStyle.Fill;
                needUpdate = false;
            }

            HideAllButThis(historique);
            if (needUpdate)
            {
                historique.UpdateGrid();
            }
        }


        #endregion

        private void SupervisionFrm_FormClosing(object sender, FormClosingEventArgs e)
        {
            SavePreset();
        }

        private void SavePreset()
        {
            if (historique != null)
            {
                historique.SavePreset();
            }
        }

        private void quitterToolStripMenuItem_Click(object sender, EventArgs e)
        {
            SavePreset();
            Application.Exit();
        }

        private void SupervisionFrm_Load(object sender, EventArgs e)
        {            
        }
        
        private void imprimerToolStripMenuItem_Click(object sender, EventArgs e)
        {            
            if ((historique != null) && (historique.Visible))
            {
                historique.Print();
            }
        }
                
        private void chargerUneArchiveToolStripMenuItem_Click(object sender, EventArgs e)
        {
            LoadArchive();    
        }

        private void LoadArchive()
        {
            OpenFileDialog ofd = new OpenFileDialog();
            ofd.Filter = "Database (*.s3db)|*.s3db";
            if (ofd.ShowDialog() == System.Windows.Forms.DialogResult.OK)
            {
                Properties.Settings.Default["DefaultConnectionString"] = "data source=" + ofd.FileName;

                RefreshConnectionString();
            }
        }

        private void RefreshConnectionString()
        {
            // et on rafraichit toutes les fenetres...
            if (historique != null)
            {
                historique.LoadData();
            }
        }

        private void generateDataToolStripMenuItem_Click(object sender, EventArgs e)
        {
            SQLiteConnection sqlite = null;

            if (sqlite == null)
            {
                sqlite = new SQLiteConnection(Settings.Default.DefaultConnectionString);
            }

            sqlite.Open();

            string SQL = "INSERT INTO SUIVI (TerminalID, MATPRISE,ARMOIREID,DATEPRISE,HEUREPRISE,MATDEPOSE,DATEDEPOSE,HEUREDEPOSE,PROCESS) VALUES";
            SQL += "(@ID, @matricule, @armoireid, @date, @heure,@Matdepose,@dateDepose,@heureDepose,@process)";

            SQLiteCommand cmd = new SQLiteCommand(SQL);
            cmd.Connection = sqlite;

            cmd.Parameters.AddWithValue("@ID", "1");
            cmd.Parameters.AddWithValue("@matricule", "1");
            cmd.Parameters.AddWithValue("@armoireid", "1");
            cmd.Parameters.AddWithValue("@date", DateTime.Now.ToString("yyyy-MM-dd"));
            cmd.Parameters.AddWithValue("@heure", DateTime.Now.ToString("HH:mm:ss"));
            cmd.Parameters.AddWithValue("@Matdepose", "1");
            cmd.Parameters.AddWithValue("@dateDepose", DateTime.Now.ToString("yyyy-MM-dd"));
            cmd.Parameters.AddWithValue("@heureDepose", DateTime.Now.ToString("HH:mm:ss"));
            cmd.Parameters.AddWithValue("@Process", "OK");

            SQLiteTransaction tra;
            tra = sqlite.BeginTransaction();

            DateTime d = DateTime.Now;
            for (int i = 0; i < 1000; i++)
            {
                string laDate = d.ToString("yyyy-MM-dd");
                string lheure = d.ToString("HH:mm:ss");

                for (int j = 0; j < 100; j++)
                {
                    cmd.Parameters.AddWithValue("@date", laDate);
                    cmd.Parameters.AddWithValue("@heure", lheure);
                    cmd.Parameters.AddWithValue("@Matdepose", "1");
                    cmd.Parameters.AddWithValue("@dateDepose", laDate);
                    cmd.Parameters.AddWithValue("@heureDepose", lheure);
                    cmd.ExecuteNonQuery();
                }

                d = d.AddDays(-1);
            }

            tra.Commit();
            sqlite.Close();

        }
    }
}
